/*
 * File   : cdrom.h
 * Purpose: This file contains all global definations of cdrom.c.
 * Autor  : Andreas Theofilu
 *
 * Copyright (C) 1999 by Theos Soft.
 */

/* 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef __CDROM_H
#define __CDROM_H

/*
 * Including this in case it's not already done
 */
#include <cdaudio.h>

#define CD_NOAUDIO	1	/* No audio CD in drive */
#define CD_INVALID	2	/* No CD in drive */
#define CD_UNKNOWN	3	/* Unknown error occured */
#define CD_LIBVERS	4	/* wrong libcdaudio version */
#define CD_EDISCID	5	/* DiscID of CD does not match */
#define CD_EDEVICE	6	/* Invalid CD-ROM drive */
#define CD_ESTATUS	7	/* No status info available */
#define CD_ECDDBEN	8	/* No or invalid CDDB-Entry */

typedef struct CDDB_ENTRY
{
	char song[81];		/* Field: TTITLE# */
	char singer[81];	/* Field: EXTT# */
	char zeit[6];		/* Get time to play directly from disc */
	long  frame;		/* Frame offset */
} cddb_entry_t;

typedef struct CDDB_TITLE
{
	unsigned long discid;	/* Computed disc-ID */
	int tracks;		/* total number of tracks */
	char title[81];		/* Field: DTITLE */
        cddb_entry_t entry[30];
} cddb_title_t;

typedef struct {
    char tag[3];
    char title[30];
    char artist[30];
    char album[30];
    char year[4];
    char comment[30];
    unsigned char genre;
} tag;

typedef struct DIRLIST
{
	char *dname;
	char title[31];
	char artist[31];
	int  minutes;
	int  seconds;
	struct DIRLIST *next;
} dirlist_t;

typedef struct
{
	char title[31];
	char artist[31];
	char album[31];
	char datum[11];
	char comment[31];
	int genre;
} id3tag_t;

typedef struct {
    int version;
    int lay;
    int error_protection;
    int bitrate_index;
    int sampling_frequency;
    int padding;
    int extension;
    int mode;
    int mode_ext;
    int copyright;
    int original;
    int emphasis;
    int stereo;
    int pcm;
} mp3header_t;

dirlist_t *cddbGetDirList (char *path, int *anz, char *filter);
void FreeDirList (dirlist_t *first);
dirlist_t *AddEntry (dirlist_t *pos, char *d_name);
int GetID3Tag (char *path, char *title, char *artist, int *minutes,
		int *seconds, unsigned long fileSize);
int get1bit (unsigned char byte, int pos);
int getbits (unsigned char byte, int start, int anz);
int cddbGetDiscInfo (Widget w, cddb_title_t *cddb, unsigned long discid, char *device, char *path, char *category);
unsigned long cddbGetDiscID (struct disc_info *disc, char *device, int *fd);
int cddb_sum (int n);
int cddbCreateCDDBEntry (char *path, cddb_title_t *cddb);
int cddbCheckEntry (char *cdfile);

/*
 * Modul: cdproto.c
 */
int GetCDDBRemote (Widget w, cddb_title_t *cddb);

#endif	/* __CDROM_H */
