/*
 * File   : options.c
 * Purpose: This file contains the routines to set some options.
 * Autor  : Andreas Theofilu
 *
 * Copyright (C) 1998, 1999, 2000 by Theos Soft.
 */

/* 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/fcntl.h>
#include <sys/stat.h>
#include <unistd.h>

#include <Xmt/Xmt.h>
#include <Xmt/Create.h>
#include <Xmt/Converters.h>
#include <Xmt/Xpm.h>
#include <Xmt/Procedures.h>
#include <Xmt/WidgetType.h>
#include <Xmt/Dialog.h>
#include <Xmt/Dialogs.h>
#include <Xmt/Chooser.h>
#include "platten.h"


typedef struct
{
	int chPrinter;
	char ipPrinter[51];
	char ipFile[51];
	char ipTrenn[2];
	char ipDatef[11];
} oppr_t;

XtResource option_resource[] = {
	{"chPrinter", "chPrinter", XtRInt, sizeof (int),
	 XtOffsetOf (oppr_t, chPrinter), XtRImmediate, NULL},
	{"ipPrinter", "ipPrinter", XmtRBuffer, XmtSizeOf (oppr_t, ipPrinter),
	 XtOffsetOf (oppr_t, ipPrinter), XtRImmediate, NULL},
	{"ipFile", "ipFile", XmtRBuffer, XmtSizeOf (oppr_t, ipFile),
	 XtOffsetOf (oppr_t, ipFile), XtRImmediate, NULL},
	{"ipTrenn", "ipTrenn", XmtRBuffer, XmtSizeOf (oppr_t, ipTrenn),
	 XtOffsetOf (oppr_t, ipTrenn), XtRImmediate, NULL},
	{"ipDatef", "ipDatef", XmtRBuffer, XmtSizeOf (oppr_t, ipDatef),
	 XtOffsetOf (oppr_t, ipDatef), XtRImmediate, NULL}
};

/*
 * Einige globale Variablen
 */
option_t option;
oppr_t oppr;
Widget OptionWidget = (Widget)0;

/*
 * Globale Funktionsdeklarationen die nur in diesem Modul verwendet
 * werden.
 */
int ReadLine (int fd, char *buf, int len);

/*
 * Handling der Dialogbox zur Eingabe von Singles
 */
void Options ()
{
	XmtDisplayBusyCursor (toplevel);

	if (!OptionWidget)
	{
	   GetResourcePath ("Option");
	   OptionWidget = XmtBuildQueryDialog (toplevel, "option", 
		option_resource, XtNumber (option_resource), NULL);

	   XmtAddDeleteCallback (XmtGetShell (OptionWidget), XmDO_NOTHING,
		XmtDialogCancelCallback, NULL);
	}

	memset ((void *)&oppr, 0, sizeof (oppr));
	oppr.chPrinter = option.chPrinter;
	strcpy (oppr.ipPrinter, option.ipPrinter);
	strcpy (oppr.ipFile, option.ipFile);
	strcpy (oppr.ipTrenn, option.ipTrenn);
	strcpy (oppr.ipDatef, option.ipDatef);

	if (XmtDialogDoSync (OptionWidget, &oppr))
	{
	   if (oppr.chPrinter > 0 && !strlen (oppr.ipFile))
	   {
	      XmtDisplayError (toplevel, "ErrorOptionField", NULL);
	      oppr.chPrinter = 0;
	      XmtDisplayDefaultCursor (toplevel);
	      return;
	   }

	   if (oppr.chPrinter == 1 && strrchr (oppr.ipFile, '.') == NULL)
	      strcat (oppr.ipFile, ".ps");

	   if (oppr.chPrinter == 2 && strrchr (oppr.ipFile, '.') == NULL)
	      strcat (oppr.ipFile, ".cvs");

	   option.chPrinter = oppr.chPrinter;
	   strcpy (option.ipPrinter, oppr.ipPrinter);
	   strcpy (option.ipFile, oppr.ipFile);
	   strcpy (option.ipTrenn, oppr.ipTrenn);
	   strcpy (option.ipDatef, oppr.ipDatef);
	   WriteOptions ();
	}

	XmtDisplayDefaultCursor (toplevel);
}

void OptionDialogInit (Widget w)
{
Widget wPrinter = XmtNameToWidget (toplevel, "*option*ipPrinter");
Widget wFile = XmtNameToWidget (toplevel, "*option*ipFile");

	switch (option.chPrinter)
	{
	   case 0: 
	      XtSetSensitive (wPrinter, True);
	      XtSetSensitive (wFile, False);
	   break;

	   case 1:
	   case 2:
	      XtSetSensitive (wPrinter, False);
	      XtSetSensitive (wFile, True);
	   break;
	}
}

void OptionChooserChangedCallback (Widget w, XtPointer tag, XtPointer data)
{
XmtChooserCallbackStruct *Chooser = (XmtChooserCallbackStruct *)data;
Widget wPrinter = XmtNameToWidget (toplevel, "*option*ipPrinter");
Widget wFile = XmtNameToWidget (toplevel, "*option*ipFile");

	switch (Chooser->item)
	{
	   case 0: 
	      XtSetSensitive (wPrinter, True);
	      XtSetSensitive (wFile, False);
	   break;

	   case 1:
	   case 2:
	      XtSetSensitive (wPrinter, False);
	      XtSetSensitive (wFile, True);
	   break;
	}
}

